@@ -1,80 +1,71 @@
 /*
-    SPDX-FileCopyrightText: 2010 Grégory Oestreicher <greg@kamago.net>
+    Copyright (c) 2010 Grégory Oestreicher <greg@kamago.net>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "davcollectionmodifyjob.h"
-#include "davjobbase_p.h"
-#include "davmanager_p.h"
+#include "davmanager.h"
 
 #include "daverror.h"
-#include "utils_p.h"
+#include "utils.h"
 
 #include <KIO/DavJob>
 #include <KIO/Job>
 
 using namespace KDAV;
 
-namespace KDAV
-{
-class DavCollectionModifyJobPrivate : public DavJobBasePrivate
-{
-public:
-    void davJobFinished(KJob *job);
-
-    DavUrl mUrl;
-    QDomDocument mQuery;
-
-    QList<QDomElement> mSetProperties;
-    QList<QDomElement> mRemoveProperties;
-};
-}
-
 DavCollectionModifyJob::DavCollectionModifyJob(const DavUrl &url, QObject *parent)
-    : DavJobBase(new DavCollectionModifyJobPrivate, parent)
+    : DavJobBase(parent), mUrl(url)
 {
-    Q_D(DavCollectionModifyJob);
-    d->mUrl = url;
 }
 
 void DavCollectionModifyJob::setProperty(const QString &prop, const QString &value, const QString &ns)
 {
-    Q_D(DavCollectionModifyJob);
     QDomElement propElement;
 
     if (ns.isEmpty()) {
-        propElement = d->mQuery.createElement(prop);
+        propElement = mQuery.createElement(prop);
     } else {
-        propElement = d->mQuery.createElementNS(ns, prop);
+        propElement = mQuery.createElementNS(ns, prop);
     }
 
-    const QDomText textElement = d->mQuery.createTextNode(value);
+    const QDomText textElement = mQuery.createTextNode(value);
     propElement.appendChild(textElement);
 
-    d->mSetProperties << propElement;
+    mSetProperties << propElement;
 }
 
 void DavCollectionModifyJob::removeProperty(const QString &prop, const QString &ns)
 {
-    Q_D(DavCollectionModifyJob);
     QDomElement propElement;
 
     if (ns.isEmpty()) {
-        propElement = d->mQuery.createElement(prop);
+        propElement = mQuery.createElement(prop);
     } else {
-        propElement = d->mQuery.createElementNS(ns, prop);
+        propElement = mQuery.createElementNS(ns, prop);
     }
 
-    d->mRemoveProperties << propElement;
+    mRemoveProperties << propElement;
 }
 
 void DavCollectionModifyJob::start()
 {
-    Q_D(DavCollectionModifyJob);
-    if (d->mSetProperties.isEmpty() && d->mRemoveProperties.isEmpty()) {
+    if (mSetProperties.isEmpty() && mRemoveProperties.isEmpty()) {
         setError(ERR_COLLECTIONMODIFY_NO_PROPERITES);
-        d->setErrorTextFromDavError();
+        setErrorTextFromDavError();
         emitResult();
         return;
     }
@@ -83,42 +74,41 @@ void DavCollectionModifyJob::start()
     QDomElement propertyUpdateElement = mQuery.createElementNS(QStringLiteral("DAV:"), QStringLiteral("propertyupdate"));
     mQuery.appendChild(propertyUpdateElement);
 
-    if (!d->mSetProperties.isEmpty()) {
+    if (!mSetProperties.isEmpty()) {
         QDomElement setElement = mQuery.createElementNS(QStringLiteral("DAV:"), QStringLiteral("set"));
         propertyUpdateElement.appendChild(setElement);
 
         QDomElement propElement = mQuery.createElementNS(QStringLiteral("DAV:"), QStringLiteral("prop"));
         setElement.appendChild(propElement);
 
-        for (const QDomElement &element : std::as_const(d->mSetProperties)) {
+        foreach (const QDomElement &element, mSetProperties) {
             propElement.appendChild(element);
         }
     }
 
-    if (!d->mRemoveProperties.isEmpty()) {
+    if (!mRemoveProperties.isEmpty()) {
         QDomElement removeElement = mQuery.createElementNS(QStringLiteral("DAV:"), QStringLiteral("remove"));
         propertyUpdateElement.appendChild(removeElement);
 
         QDomElement propElement = mQuery.createElementNS(QStringLiteral("DAV:"), QStringLiteral("prop"));
         removeElement.appendChild(propElement);
 
-        for (const QDomElement &element : std::as_const(d->mSetProperties)) {
+        foreach (const QDomElement &element, mSetProperties) {
             propElement.appendChild(element);
         }
     }
 
-    KIO::DavJob *job = DavManager::self()->createPropPatchJob(d->mUrl.url(), mQuery.toString());
+    KIO::DavJob *job = DavManager::self()->createPropPatchJob(mUrl.url(), mQuery);
     job->addMetaData(QStringLiteral("PropagateHttpHeader"), QStringLiteral("true"));
-    connect(job, &KIO::DavJob::result, this, [d](KJob *job) {
-        d->davJobFinished(job);
-    });
+    connect(job, &KIO::DavJob::result, this, &DavCollectionModifyJob::davJobFinished);
 }
 
-void DavCollectionModifyJobPrivate::davJobFinished(KJob *job)
+void DavCollectionModifyJob::davJobFinished(KJob *job)
 {
     KIO::DavJob *davJob = qobject_cast<KIO::DavJob *>(job);
-    const QString responseCodeStr = davJob->queryMetaData(QStringLiteral("responsecode"));
-    const int responseCode = responseCodeStr.isEmpty() ? 0 : responseCodeStr.toInt();
+    const int responseCode = davJob->queryMetaData(QStringLiteral("responsecode")).isEmpty() ?
+                             0 :
+                             davJob->queryMetaData(QStringLiteral("responsecode")).toInt();
 
     // KIO::DavJob does not set error() even if the HTTP status code is a 4xx or a 5xx
     if (davJob->error() || (responseCode >= 400 && responseCode < 600)) {
@@ -131,11 +121,11 @@ void DavCollectionModifyJobPrivate::davJobFinished(KJob *job)
         return;
     }
 
-    QDomDocument response;
-    response.setContent(davJob->responseData(), true);
+    const QDomDocument response = davJob->response();
     QDomElement responseElement = Utils::firstChildElementNS(response.documentElement(), QStringLiteral("DAV:"), QStringLiteral("response"));
 
     bool hasError = false;
+    QString errorText;
 
     // parse all propstats answers to get the eventual errors
     const QDomNodeList propstats = responseElement.elementsByTagNameNS(QStringLiteral("DAV:"), QStringLiteral("propstat"));
@@ -144,7 +134,7 @@ void DavCollectionModifyJobPrivate::davJobFinished(KJob *job)
         const QDomElement statusElement = Utils::firstChildElementNS(propstatElement, QStringLiteral("DAV:"), QStringLiteral("status"));
 
         const QString statusText = statusElement.text();
-        if (statusText.contains(QLatin1String("200"))) {
+        if (statusText.contains(QStringLiteral("200"))) {
             continue;
         } else {
             // Generic error
@@ -157,8 +147,7 @@ void DavCollectionModifyJobPrivate::davJobFinished(KJob *job)
         setError(ERR_COLLECTIONMODIFY_RESPONSE);
 
         // Trying to get more information about the error
-        const QDomElement responseDescriptionElement =
-            Utils::firstChildElementNS(responseElement, QStringLiteral("DAV:"), QStringLiteral("responsedescription"));
+        const QDomElement responseDescriptionElement = Utils::firstChildElementNS(responseElement, QStringLiteral("DAV:"), QStringLiteral("responsedescription"));
         if (!responseDescriptionElement.isNull()) {
             setJobErrorText(responseDescriptionElement.text());
         }
@@ -167,5 +156,3 @@ void DavCollectionModifyJobPrivate::davJobFinished(KJob *job)
 
     emitResult();
 }
-
-#include "moc_davcollectionmodifyjob.cpp"
